OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "No contacts in here" : "Nie ma tu żadnych kontaktów",
    "Name" : "Nazwa",
    "Organization" : "Organizacja",
    "Title" : "Tytuł",
    "Add field ..." : "Dodaj pole ...",
    "Add contact" : "Dodaj kontakt",
    "No search result for {query}" : "Brak wyników wyszukiwania dla zapytania {query}",
    "All contacts" : "Wszystkie kontakty",
    "Not grouped" : "Nie zgrupowane",
    "Post Office Box" : "Skrytka Pocztowa",
    "Postal Code" : "Kod Pocztowy",
    "City" : "Miasto",
    "State or province" : "Województwo ",
    "Country" : "Kraj",
    "Address" : "Adres",
    "(new group)" : "Nowa grupa",
    "{addressbook} shared by {owner}" : "Książka {addressbook} udostępniona przez {owner}",
    "Nickname" : "Nazwa",
    "Notes" : "Notatki",
    "Website" : "Strona www",
    "Home" : "Strona główna",
    "Work" : "Zawodowe",
    "Other" : "Inne",
    "Groups" : "Grupy",
    "Birthday" : "Urodziny",
    "Email" : "Email",
    "Instant messaging" : "Szybkie wiadomości",
    "Phone" : "Telefon",
    "Mobile" : "Komórka",
    "Fax" : "Faks",
    "Fax home" : "Faks domowy",
    "Fax work" : "Fakx pracowy",
    "Pager" : "Pager",
    "Voice" : "Połączenie głosowe",
    "Settings" : "Ustawienia",
    "Import" : "Importuj"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
